@@ -1,8 +1,6 @@
 package Astro::ADS;
-# ABSTRACT: Perl library to connect with the Harvard Astrophysical Data Service
-# https://ads.harvard.edu/
-$Astro::ADS::VERSION = '1.90_50'; # TRIAL
-$Astro::ADS::VERSION = '1.9050';
+$Astro::ADS::VERSION = '1.90_60'; # TRIAL
+$Astro::ADS::VERSION = '1.9060';
 use Moo;
 
 use Carp;
@@ -51,7 +49,7 @@ sub _build_token {
         return $key;
     }
 
-    croak 'You need to provide an API token';
+    croak "You need to provide an API token.\nSee https://metacpan.org/pod/Astro::ADS#Getting-Started\n";
 }
 
 sub get_response {
@@ -96,8 +94,6 @@ sub post_response {
 
 1; # Perl is my Igor
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -108,7 +104,7 @@ Astro::ADS - Perl library to connect with the Harvard Astrophysical Data Service
 
 =head1 VERSION
 
-version 1.90_50
+version 1.90
 
 =head1 SYNOPSIS
 
@@ -154,10 +150,6 @@ bottom of L<About ADS|https://ui.adsabs.harvard.edu/about/>.
 To acknowlegde use of this module, it will be sufficient to mention
 I<Perl's Astro::ADS is available at https://metacpan.org/pod/Astro::ADS>
 
-=head1 AUTHOR
-
-Boyd Duffee <duffee@cpan.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
