@@ -1,9 +1,7 @@
 package Astro::ADS::Result;
-# ABSTRACT: A class for the results of a Search
-$Astro::ADS::Result::VERSION = '1.90_50'; # TRIAL
-$Astro::ADS::Result::VERSION = '1.9050';
+$Astro::ADS::Result::VERSION = '1.90_60'; # TRIAL
+$Astro::ADS::Result::VERSION = '1.9060';
 use Moo;
-#extends 'Astro::ADS';
 
 use Carp;
 use Data::Dumper::Concise;
@@ -33,7 +31,7 @@ has [qw/start rows/] => (
 );
 has error => (
     is       => 'rw',
-    isa      => Str,
+    isa      => HashRef[]
 );
 has docs => (
     is      => 'rw',
@@ -47,7 +45,7 @@ has docs => (
 before [qw/numFound numFoundExact start rows docs/] => sub {
    my ($self) = @_;
    if ($self->error ) {
-       carp 'Empty Result object: ', $self->error;
+       carp 'Empty Result object: ', $self->error->{message};
    }
 };
 
@@ -101,8 +99,6 @@ sub get_papers {
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -113,7 +109,7 @@ Astro::ADS::Result - A class for the results of a Search
 
 =head1 VERSION
 
-version 1.90_50
+version 1.90
 
 =head1 SYNOPSIS
 
@@ -170,10 +166,6 @@ If given an argument, it takes that as the number of rows to fetch.
 
 =back
 
-=head1 AUTHOR
-
-Boyd Duffee <duffee@cpan.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
