@@ -1,7 +1,6 @@
 package Astro::ADS::Search;
-# ABSTRACT: Queries the ADS Search endpoint and collects the results
-$Astro::ADS::Search::VERSION = '1.90_50'; # TRIAL
-$Astro::ADS::Search::VERSION = '1.9050';
+$Astro::ADS::Search::VERSION = '1.90_60'; # TRIAL
+$Astro::ADS::Search::VERSION = '1.9060';
 use Moo;
 extends 'Astro::ADS';
 with 'Astro::ADS::Role::ResultMapper';
@@ -66,7 +65,12 @@ sub query {
     my $response = $self->get_response( $url );
     if ( $response->is_error ) {
         carp $response->message;
-        return Astro::ADS::Result->new( {error => $response->message} );
+        my $error_obj = {
+            message => $response->message,
+            query   => $search_terms,
+            url     => $url,
+        };
+        return Astro::ADS::Result->new( {error => $error_obj} );
     }
 
     my $json = $response->json;
@@ -159,8 +163,6 @@ sub add_objects {
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -171,7 +173,7 @@ Astro::ADS::Search - Queries the ADS Search endpoint and collects the results
 
 =head1 VERSION
 
-version 1.90_50
+version 1.90
 
 =head1 SYNOPSIS
 
@@ -253,10 +255,6 @@ available with the author and title fields
 
 =back
 
-=head1 AUTHOR
-
-Boyd Duffee <duffee@cpan.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2025 by Boyd Duffee.
